##  Step 3: Configure General Field Mapping (Optional)
Map general fields to define how data should sync between Jira and SAP LeanIX. Learn more about supported mappings in [Setting Up the Integration](https://help.sap.com/docs/leanix/ea/jira-integration?locale=en-US&state=PRODUCTION&version=CLOUD#loiod7f51b4055b34ae88b34fc4ce58b834e__Setting-Up-the-Integration).
**Note**
Fields must already exist in SAP LeanIX to be available for mapping.
To configure general field mapping, do the following:
  1. Under General Mapping, choose Add Field Mapping.
  2. Select an SAP LeanIX Field
For example, Name.
  3. Map it to a corresponding Jira field.
For example, Summary.
  4. Choose the sync direction.
For example, SAP LeanIX to Jira.


Repeat this step for all fields that you want to map.
